using BPA.SAAS.Manage.Application.DataBase.Dtos.GoodsType;
using BPA.SAAS.Manage.Core.Base;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace BPA.SAAS.Manage.Application.DataBase.Interface
{
    public interface IGoodsTypeService
    {
        /// <summary>
        /// 分页查询
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        Task<PageUtil> GetGoodsTypePage(GoodsTypeQueryDto dto);
        Task<List<dynamic>> GetGoodsTypeList_alm();
        /// <summary>
        /// 添加商品类型
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        Task<bool> AddGoodsType(GoodsTypeDto dto);
        /// <summary>
        /// 更新商品类型
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        Task<bool> UpdateGoodsType(GoodsTypeDto dto);
        /// <summary>
        /// 删除商品类型
        /// </summary>
        /// <param name="Id"></param>
        /// <returns></returns>
       Task<bool> DelGoodsType(string Id);
        /// <summary>
        /// 查询商品类型树结构
        /// </summary>
        /// <returns></returns>
        Task<dynamic> GetGoodsTypeTree();
    }
}
